package com.ruoyi.tc.entity;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ruoyi.common.annotation.Excel;
import com.ruoyi.tc.baseClass.BaseClass;
import com.ruoyi.tc.entity.request.AssetOfficialAccountMenu;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serializable;
import java.util.List;

/**
 * 公众号资产表(asset_official_account)实体类
 *
 * @author du
 * @since 2024/11/13 14:44
 */
@Data
@ApiModel("公众号资产表")
@TableName(value = "asset_official_account")
public class AssetOfficialAccount extends BaseClass implements Serializable {


    @ApiModelProperty("id")
    @TableId(value = "id",type = IdType.AUTO)
    private Long id;

    @ApiModelProperty("组织机构名称（部门名称）")
    @TableField(exist = false)
    private String deptName;

    /**
     * 所属单位
     */
    @Excel(name = "所属单位", sort = 1, width = 24)
    @ApiModelProperty("所属单位")
    private String ssdw;

    /**
     * 公众号名称
     */
    @Excel(name = "公众号名称", sort = 2, width = 20)
    @ApiModelProperty("公众号名称")
    private String gzhmc;
    /**
     * 微信号
     */
    @Excel(name = "微信号", sort = 3, width = 22)
    @ApiModelProperty("微信号")
    private String wxh;
    /**
     * 认证主体
     */
    @Excel(name = "认证主体", sort = 4, width = 24)
    @ApiModelProperty("认证主体")
    private String rzzt;
    /**
     * 统一社会信用代码
     */
    @Excel(name = "统一社会信用代码", sort = 5, width = 24)
    @ApiModelProperty("统一社会信用代码")
    private String tyshxydm;
    /**
     * 公众号状态（字典）
     */
    @Excel(name = "公众号状态", sort = 6, dictType = "gzh_state", comboReadDict = true)
    @ApiModelProperty("公众号状态（字典）")
    private String gzhzt;
    /**
     * 公众号id
     */
    @Excel(name = "公众号ID", sort = 7)
    @ApiModelProperty("公众号id")
    private String gzhId;
    /**
     * 公众号类型（字典）
     */
    @Excel(name = "公众号类型", sort = 8, dictType = "gzh_lx", comboReadDict = true)
    @ApiModelProperty("公众号类型（字典）")
    private String gzhlx;
    /**
     * 认证状态（字典）
     */
    @Excel(name = "认证状态", sort = 9, dictType = "gzh_rzzt", comboReadDict = true)
    @ApiModelProperty("认证状态（字典）")
    private String rzState;
    /**
     * 认证时间
     */
    @Excel(name = "认证时间", sort = 10)
    @ApiModelProperty("认证时间")
    private String rzsj;
    /**
     * 认证类型（字典）
     */
    @Excel(name = "认证类型", sort = 11, dictType = "gzh_rzlx", comboReadDict = true)
    @ApiModelProperty("认证类型（字典）")
    private String rzlx;
    /**
     * 所属行业（字典）
     */
    @Excel(name = "所属行业", dictType = "app_sshy", comboReadDict = true, sort = 12, width = 18)
    @ApiModelProperty("所属行业（字典）")
    private String sshy;
    /**
     * 重点行业（字典）
     */
    @Excel(name = "重点行业", dictType = "app_zdhy", comboReadDict = true, sort = 13, width = 18)
    @ApiModelProperty("重点行业（字典）")
    private String zdhy;
    /**
     * 行政区划（字典）
     */
    @Excel(name = "行政区划", dictType = "app_xzqh", comboReadDict = true, sort = 14, width = 18)
    @ApiModelProperty("行政区划（字典）")
    private String xzqh;
    /**
     * 系统简介
     */
    @Excel(name = "系统简介", sort = 15, width = 26)
    @ApiModelProperty("系统简介")
    private String xtjj;
    /**
     * 系统责任人
     */
    @Excel(name = "系统责任人", sort = 16)
    @ApiModelProperty("系统责任人")
    private String xtzrr;
    /**
     * 系统责任人电话
     */
    @Excel(name = "系统责任人电话", sort = 17)
    @ApiModelProperty("系统责任人电话")
    private String xtzrrdh;
    /**
     * 系统责任人邮箱
     */
    @Excel(name = "系统责任人邮箱", sort = 18)
    @ApiModelProperty("系统责任人邮箱")
    private String xtzrryx;
    /**
     * 系统责任人地址
     */
    @Excel(name = "系统责任人地址", sort = 19)
    @ApiModelProperty("系统责任人地址")
    private String xtzrrdz;
    /**
     * 菜单名称
     */
    @Excel(name = "菜单信息（菜单名称）", sort = 20)
    @ApiModelProperty("菜单名称")
    private String cdmc;
    /**
     * 菜单链接
     */
    @Excel(name = "菜单信息（菜单链接）", sort = 21,width = 28)
    @ApiModelProperty("菜单链接")
    private String cdlj;
    /**
     * 菜单类型
     */
    @Excel(name = "菜单信息（菜单类型）", sort = 22)
    @ApiModelProperty("菜单类型")
    private String cdlx;

    /**
     * 菜单数组
     */
    @TableField(exist = false)
    @ApiModelProperty("菜单类型")
    private List<AssetOfficialAccountMenu> cdList;

    @ApiModelProperty("是否报废")
    private Integer isbf=0;
    /**
     * 删除标志（0代表存在 2代表删除）
     */
    @ApiModelProperty("删除标志（0代表存在 2代表删除）")
    private String delFlag;

    /**
     * 平台类型
     */
    @Excel(name = "平台类型", sort = 99,readConverterExp = "1=微信,2=抖音,3=微博,4=今日头条,5=快手,6=B站,7=小红书")
    @ApiModelProperty("平台类型")
    private String ptlx;

    /**
     * 粉丝数
     */
    @ApiModelProperty("粉丝数")
    @Excel(name = "粉丝数", sort = 100)
    private String fss;

    /**
     * 审核
     */
    @ApiModelProperty("审核")
    @TableField(exist = false)
    private String auditState;
}
